==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/QUALIFICATIONSOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour QUALIFICATIONSOURCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="QUALIFICATIONSOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONSOURCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUALIFICATIONSOURCEID_Type", propOrder = {
    "qualificationsource",
    "description"
})
public class QUALIFICATIONSOURCEID_Type {

    @XmlElement(name = "QUALIFICATIONSOURCE", required = true)
    protected String qualificationsource;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété qualificationsource.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUALIFICATIONSOURCE() {
        return qualificationsource;
    }

    /**
     * Définit la valeur de la propriété qualificationsource.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUALIFICATIONSOURCE(String value) {
        this.qualificationsource = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/QUALIFICATIONSOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QUALIFICATIONSOURCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QUALIFICATIONSOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONSOURCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUALIFICATIONSOURCEID_Type", propOrder = {
    "qualificationsource",
    "description"
})
public class QUALIFICATIONSOURCEID_Type {

    @XmlElement(name = "QUALIFICATIONSOURCE", required = true)
    protected String qualificationsource;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the qualificationsource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUALIFICATIONSOURCE() {
        return qualificationsource;
    }

    /**
     * Sets the value of the qualificationsource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUALIFICATIONSOURCE(String value) {
        this.qualificationsource = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
